@@ -22,7 +22,7 @@ Description:
 
 CVS Information:
 
-  $Source: /home/globdev/CVS/globus-packages/common/source/library/globus_thread_sproc.c,v $
+  $Source: /home/globdev/CVS/globus-packages/common/source/library/Attic/globus_thread_sproc.c,v $
   $Date: 2006/01/19 05:54:14 $
   $Revision: 1.7 $
   $State: Exp $
